// java wrapper for vtkGradientFilter object
//

package vtk;
import vtk.*;

public class vtkGradientFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputScalars_2(int id0,String id1);
  public void SetInputScalars(int id0,String id1)
    { SetInputScalars_2(id0,id1); }

  private native void SetInputScalars_3(int id0,int id1);
  public void SetInputScalars(int id0,int id1)
    { SetInputScalars_3(id0,id1); }

  private native String GetResultArrayName_4();
  public String GetResultArrayName()
    { return GetResultArrayName_4(); }

  private native void SetResultArrayName_5(String id0);
  public void SetResultArrayName(String id0)
    { SetResultArrayName_5(id0); }

  private native String GetDivergenceArrayName_6();
  public String GetDivergenceArrayName()
    { return GetDivergenceArrayName_6(); }

  private native void SetDivergenceArrayName_7(String id0);
  public void SetDivergenceArrayName(String id0)
    { SetDivergenceArrayName_7(id0); }

  private native String GetVorticityArrayName_8();
  public String GetVorticityArrayName()
    { return GetVorticityArrayName_8(); }

  private native void SetVorticityArrayName_9(String id0);
  public void SetVorticityArrayName(String id0)
    { SetVorticityArrayName_9(id0); }

  private native String GetQCriterionArrayName_10();
  public String GetQCriterionArrayName()
    { return GetQCriterionArrayName_10(); }

  private native void SetQCriterionArrayName_11(String id0);
  public void SetQCriterionArrayName(String id0)
    { SetQCriterionArrayName_11(id0); }

  private native int GetFasterApproximation_12();
  public int GetFasterApproximation()
    { return GetFasterApproximation_12(); }

  private native void SetFasterApproximation_13(int id0);
  public void SetFasterApproximation(int id0)
    { SetFasterApproximation_13(id0); }

  private native void FasterApproximationOn_14();
  public void FasterApproximationOn()
    { FasterApproximationOn_14(); }

  private native void FasterApproximationOff_15();
  public void FasterApproximationOff()
    { FasterApproximationOff_15(); }

  private native void SetComputeGradient_16(int id0);
  public void SetComputeGradient(int id0)
    { SetComputeGradient_16(id0); }

  private native int GetComputeGradient_17();
  public int GetComputeGradient()
    { return GetComputeGradient_17(); }

  private native void ComputeGradientOn_18();
  public void ComputeGradientOn()
    { ComputeGradientOn_18(); }

  private native void ComputeGradientOff_19();
  public void ComputeGradientOff()
    { ComputeGradientOff_19(); }

  private native void SetComputeDivergence_20(int id0);
  public void SetComputeDivergence(int id0)
    { SetComputeDivergence_20(id0); }

  private native int GetComputeDivergence_21();
  public int GetComputeDivergence()
    { return GetComputeDivergence_21(); }

  private native void ComputeDivergenceOn_22();
  public void ComputeDivergenceOn()
    { ComputeDivergenceOn_22(); }

  private native void ComputeDivergenceOff_23();
  public void ComputeDivergenceOff()
    { ComputeDivergenceOff_23(); }

  private native void SetComputeVorticity_24(int id0);
  public void SetComputeVorticity(int id0)
    { SetComputeVorticity_24(id0); }

  private native int GetComputeVorticity_25();
  public int GetComputeVorticity()
    { return GetComputeVorticity_25(); }

  private native void ComputeVorticityOn_26();
  public void ComputeVorticityOn()
    { ComputeVorticityOn_26(); }

  private native void ComputeVorticityOff_27();
  public void ComputeVorticityOff()
    { ComputeVorticityOff_27(); }

  private native void SetComputeQCriterion_28(int id0);
  public void SetComputeQCriterion(int id0)
    { SetComputeQCriterion_28(id0); }

  private native int GetComputeQCriterion_29();
  public int GetComputeQCriterion()
    { return GetComputeQCriterion_29(); }

  private native void ComputeQCriterionOn_30();
  public void ComputeQCriterionOn()
    { ComputeQCriterionOn_30(); }

  private native void ComputeQCriterionOff_31();
  public void ComputeQCriterionOff()
    { ComputeQCriterionOff_31(); }

  private native void SetContributingCellOption_32(int id0);
  public void SetContributingCellOption(int id0)
    { SetContributingCellOption_32(id0); }

  private native int GetContributingCellOptionMinValue_33();
  public int GetContributingCellOptionMinValue()
    { return GetContributingCellOptionMinValue_33(); }

  private native int GetContributingCellOptionMaxValue_34();
  public int GetContributingCellOptionMaxValue()
    { return GetContributingCellOptionMaxValue_34(); }

  private native int GetContributingCellOption_35();
  public int GetContributingCellOption()
    { return GetContributingCellOption_35(); }

  private native void SetReplacementValueOption_36(int id0);
  public void SetReplacementValueOption(int id0)
    { SetReplacementValueOption_36(id0); }

  private native int GetReplacementValueOptionMinValue_37();
  public int GetReplacementValueOptionMinValue()
    { return GetReplacementValueOptionMinValue_37(); }

  private native int GetReplacementValueOptionMaxValue_38();
  public int GetReplacementValueOptionMaxValue()
    { return GetReplacementValueOptionMaxValue_38(); }

  private native int GetReplacementValueOption_39();
  public int GetReplacementValueOption()
    { return GetReplacementValueOption_39(); }

  public vtkGradientFilter() { super(); }

  public vtkGradientFilter(long id) { super(id); }
  public native long   VTKInit();

}
